@@ -17,6 +17,24 @@ class View;
 
 typedef std::pair<std::string, std::string> QnaPair;
 
+enum class CommandType {
+	QUIT,
+	SAVE,
+	GOTO,
+	TAG,
+	SET,
+	SOURCE,
+	DUMPCONFIG,
+	EXEC,
+	UNKNOWN,	/// Unknown/non-existing command. Tokenized input is stored in Command.args
+	INVALID, 	/// differs from UNKNOWN in that no input was parsed
+};
+
+struct Command {
+	CommandType type;
+	std::vector<std::string> args;
+};
+
 class FormAction {
 public:
 	FormAction(View*, std::string formstr, ConfigContainer* cfg);
@@ -40,7 +58,6 @@ public:
 	void recalculate_widget_dimensions();
 
 	virtual void handle_cmdline(const std::string& cmd);
-	bool handle_single_argument_set(std::string argument);
 
 	bool process_op(Operation op,
 		bool automatic = false,
@@ -50,11 +67,6 @@ public:
 
 	void start_cmdline(std::string default_value = "");
 
-	std::string get_qna_response(unsigned int i)
-	{
-		return (qna_responses.size() >= (i + 1)) ? qna_responses[i]
-			: "";
-	}
 	void start_qna(const std::vector<QnaPair>& prompts,
 		Operation finish_op,
 		History* h = nullptr);
@@ -92,9 +104,13 @@ protected:
 
 	void start_bookmark_qna(const std::string& default_title,
 		const std::string& default_url,
-		const std::string& default_desc,
 		const std::string& default_feed_title);
 
+	static Command parse_command(const std::string& input,
+		std::string delimiters = " \r\n\t");
+
+	void handle_parsed_command(const Command& command);
+
 	View* v;
 	ConfigContainer* cfg;
 	Stfl::Form f;
@@ -109,6 +125,12 @@ protected:
 
 private:
 	void start_next_question();
+	bool handle_single_argument_set(std::string argument);
+	void handle_set(const std::vector<std::string>& args);
+	void handle_quit();
+	void handle_source(const std::vector<std::string>& args);
+	void handle_dumpconfig(const std::vector<std::string>& args);
+	void handle_exec(const std::vector<std::string>& args);
 
 	std::vector<QnaPair> qna_prompts;
 	Operation finish_operation;
