@@ -2,30 +2,31 @@
 #define NEWSBOAT_VIEW_H_
 
 #include <cstdint>
-#include <list>
 #include <mutex>
 #include <string>
 #include <vector>
 
 #include "3rd-party/optional.hpp"
 
-#include "colormanager.h"
-#include "configcontainer.h"
-#include "controller.h"
-#include "dirbrowserformaction.h"
-#include "feedlistformaction.h"
-#include "filebrowserformaction.h"
 #include "htmlrenderer.h"
-#include "keymap.h"
-#include "regexmanager.h"
 #include "statusline.h"
-#include "stflpp.h"
 
 namespace newsboat {
 
+class Cache;
+class ColorManager;
+class Controller;
+class ConfigContainer;
+class FeedListFormAction;
+class FilterContainer;
+struct FilterNameExprPair;
+class FormAction;
 class ItemListFormAction;
 class ItemViewFormAction;
-class FeedListFormAction;
+class KeyMap;
+struct MacroCmd;
+class RegexManager;
+class RssFeed;
 
 class View : public IStatus {
 public:
@@ -83,12 +84,12 @@ public:
 
 	std::string run_filebrowser(const std::string& default_filename = "");
 	std::string run_dirbrowser();
-	std::string select_tag();
+	std::string select_tag(const std::string& current_tag);
 	std::string select_filter(
 		const std::vector<FilterNameExprPair>& filters);
 
 	nonstd::optional<std::uint8_t> open_in_browser(const std::string& url,
-		const std::string& feedurl, bool interactive);
+		const std::string& feedurl, const std::string& type, bool interactive);
 	void open_in_pager(const std::string& filename);
 
 	std::string get_filename_suggestion(const std::string& s);
@@ -169,8 +170,6 @@ protected:
 
 	RegexManager& rxman;
 
-	std::map<std::string, TextStyle> text_styles;
-
 	bool is_inside_qna;
 	bool is_inside_cmdline;
 
