@@ -134,7 +134,7 @@ pub fn censor_url(url: &str) -> String {
 
 /// Quote a string for use with stfl by replacing all occurences of "<" with "<>"
 pub fn quote_for_stfl(string: &str) -> String {
-    string.replace("<", "<>")
+    string.replace('<', "<>")
 }
 
 /// Get basename from a URL if available else return an empty string
@@ -169,7 +169,7 @@ pub fn trim_end(rs_str: String) -> String {
 }
 
 pub fn quote(input: String) -> String {
-    let mut input = input.replace("\"", "\\\"");
+    let mut input = input.replace('\"', "\\\"");
     input.insert(0, '"');
     input.push('"');
     input
@@ -315,7 +315,7 @@ pub fn substr_with_width_stfl(string: &str, max_width: usize) -> String {
 }
 
 /// Remove all soft-hyphens as they can behave unpredictably (see
-/// https://github.com/akrennmair/newsbeuter/issues/259#issuecomment-259609490) and inadvertently
+/// <https://github.com/akrennmair/newsbeuter/issues/259#issuecomment-259609490>) and inadvertently
 /// render as hyphens
 pub fn remove_soft_hyphens(text: &mut String) {
     text.retain(|c| c != '\u{00AD}')
@@ -391,7 +391,7 @@ pub fn get_auth_method(method: &str) -> c_ulong {
 
 pub fn unescape_url(rs_str: String) -> Option<String> {
     let decoded = percent_decode(rs_str.as_bytes()).decode_utf8();
-    decoded.ok().map(|s| s.replace("\0", ""))
+    decoded.ok().map(|s| s.replace('\0', ""))
 }
 
 /// Runs given command in a shell, and returns the output (from stdout; stderr is printed to the
@@ -787,9 +787,11 @@ pub fn tokenize_quoted(line: &str, delimiters: &str) -> Vec<String> {
 
 /// The result of executing `extract_filter()`.
 pub struct FilterUrlParts {
+    #[allow(rustdoc::bare_urls)]
     /// "~/bin/foo.sh" in "filter:~/bin/foo.sh:https://example.com/news.atom"
     pub script_name: String,
 
+    #[allow(rustdoc::bare_urls)]
     /// "https://example.com/news.atom" in "filter:~/bin/foo.sh:https://example.com/news.atom"
     pub url: String,
 }
