@@ -31,10 +31,10 @@
 #include "configexception.h"
 #include "configpaths.h"
 #include "dbexception.h"
-#include "downloadthread.h"
 #include "exception.h"
 #include "feedhqapi.h"
 #include "feedhqurlreader.h"
+#include "formaction.h"
 #include "freshrssapi.h"
 #include "freshrssurlreader.h"
 #include "fileurlreader.h"
