@@ -9,6 +9,7 @@
 #include <string>
 
 #include "config.h"
+#include "controller.h"
 #include "dbexception.h"
 #include "feedcontainer.h"
 #include "fmtstrformatter.h"
@@ -31,11 +32,11 @@ FeedListFormAction::FeedListFormAction(View* vv,
 	RegexManager& r)
 	: ListFormAction(vv, formstr, "feeds", cfg)
 	, zero_feedpos(false)
-	, apply_filter(false)
+	, filter_active(false)
 	, filterpos(0)
 	, set_filterpos(false)
 	, rxman(r)
-	, filters(f)
+	, filter_container(f)
 	, cache(cc)
 {
 	valid_cmds.push_back("tag");
@@ -286,6 +287,11 @@ REDO:
 					"reload-only-visible-feeds");
 			std::vector<int> idxs;
 			if (reload_only_visible_feeds) {
+				if (visible_feeds.empty()) {
+					// Do not reload *all* feeds, when
+					// there is no visible feeds at all.
+					break;
+				}
 				for (const auto& feed : visible_feeds) {
 					idxs.push_back(feed.second);
 				}
@@ -413,7 +419,7 @@ REDO:
 		if (automatic && args->size() > 0) {
 			newtag = (*args)[0];
 		} else {
-			newtag = v->select_tag();
+			newtag = v->select_tag(tag);
 		}
 		if (newtag != "") {
 			tag = newtag;
@@ -423,30 +429,20 @@ REDO:
 	}
 	break;
 	case OP_SELECTFILTER:
-		if (filters.size() > 0) {
-			std::string newfilter;
+		if (filter_container.size() > 0) {
 			if (automatic && args->size() > 0) {
-				newfilter = (*args)[0];
-			} else {
-				newfilter = v->select_filter(
-						filters.get_filters());
-			}
-			if (newfilter != "") {
-				filterhistory.add_line(newfilter);
-				if (newfilter.length() > 0) {
-					if (!matcher.parse(newfilter)) {
-						v->get_statusline().show_error(strprintf::fmt(
-								_("Error: couldn't "
-									"parse filter "
-									"expression `%s': %s"),
-								newfilter,
-								matcher.get_parse_error()));
-					} else {
-						save_filterpos();
-						apply_filter = true;
-						do_redraw = true;
-					}
+				const std::string filter_name = (*args)[0];
+				const auto filter = filter_container.get_filter(filter_name);
+
+				if (filter.has_value()) {
+					apply_filter(filter.value());
+				} else {
+					v->get_statusline().show_error(strprintf::fmt(_("No filter found with name `%s'."),
+							filter_name));
 				}
+			} else {
+				const std::string filter_text = v->select_filter(filter_container.get_filters());
+				apply_filter(filter_text);
 			}
 		} else {
 			v->get_statusline().show_error(_("No filters defined."));
@@ -481,7 +477,7 @@ REDO:
 		}
 		break;
 	case OP_CLEARFILTER:
-		apply_filter = false;
+		filter_active = false;
 		do_redraw = true;
 		save_filterpos();
 		break;
@@ -558,10 +554,13 @@ bool FeedListFormAction::open_position_in_browser(unsigned int pos,
 		interactive ? "true" : "false");
 
 	std::string url;
+	std::string type;
 	if (!feed->link().empty()) {
 		url = feed->link();
+		type = "feed";
 	} else if (!feed->rssurl().empty()) {
 		url = feed->rssurl();
+		type = "rssfeed";
 	} else {
 		// rssurl can't be empty, so if we got to this branch,
 		// something is clearly wrong with Newsboat internals.
@@ -575,7 +574,7 @@ bool FeedListFormAction::open_position_in_browser(unsigned int pos,
 
 	if (!url.empty()) {
 		const std::string feedurl = feed->rssurl();
-		const auto exit_code = v->open_in_browser(url, feedurl, interactive);
+		const auto exit_code = v->open_in_browser(url, feedurl, type, interactive);
 		if (!exit_code.has_value()) {
 			v->get_statusline().show_error(_("Failed to spawn browser"));
 			return false;
@@ -602,7 +601,7 @@ void FeedListFormAction::update_visible_feeds(
 		feed->set_index(i + 1);
 		if ((tag == "" || feed->matches_tag(tag)) &&
 			(show_read || feed->unread_item_count() > 0) &&
-			(!apply_filter || matcher.matches(feed.get())) &&
+			(!filter_active || matcher.matches(feed.get())) &&
 			!feed->hidden()) {
 			visible_feeds.push_back(FeedPtrPosPair(feed, i));
 		}
@@ -948,7 +947,7 @@ void FeedListFormAction::update_form_title(unsigned int width)
 	fmt.register_fmt('u', std::to_string(count_unread_feeds()));
 	fmt.register_fmt('U', std::to_string(count_unread_articles()));
 	fmt.register_fmt('t', std::to_string(visible_feeds.size()));
-	fmt.register_fmt('F', apply_filter ? matcher.get_expression() : "");
+	fmt.register_fmt('F', filter_active ? matcher.get_expression() : "");
 
 	set_value("head", fmt.do_format(title_format, width));
 }
@@ -975,18 +974,7 @@ unsigned int FeedListFormAction::count_unread_articles()
 void FeedListFormAction::op_end_setfilter()
 {
 	std::string filtertext = qna_responses[0];
-	filterhistory.add_line(filtertext);
-	if (filtertext.length() > 0) {
-		if (!matcher.parse(filtertext)) {
-			v->get_statusline().show_error(strprintf::fmt(
-					_("Error: couldn't parse filter expression `%s': %s"),
-					filtertext, matcher.get_parse_error()));
-		} else {
-			save_filterpos();
-			apply_filter = true;
-			do_redraw = true;
-		}
-	}
+	apply_filter(filtertext);
 }
 
 void FeedListFormAction::op_start_search()
@@ -1115,4 +1103,23 @@ std::string FeedListFormAction::title()
 			static_cast<unsigned int>(visible_feeds.size()));
 }
 
+void FeedListFormAction::apply_filter(const std::string& filtertext)
+{
+	if (filtertext.empty()) {
+		return;
+	}
+
+	filterhistory.add_line(filtertext);
+	if (!matcher.parse(filtertext)) {
+		v->get_statusline().show_error(strprintf::fmt(
+				_("Error: couldn't parse filter expression `%s': %s"),
+				filtertext,
+				matcher.get_parse_error()));
+	} else {
+		save_filterpos();
+		filter_active = true;
+		do_redraw = true;
+	}
+}
+
 } // namespace newsboat
