@@ -24,14 +24,20 @@ extern "C" {
 }
 
 #include "config.h"
+#include "colormanager.h"
+#include "controller.h"
+#include "configcontainer.h"
 #include "dbexception.h"
 #include "dialogs.h"
 #include "dialogsformaction.h"
+#include "dirbrowserformaction.h"
 #include "emptyformaction.h"
 #include "empty.h"
 #include "exception.h"
 #include "feedlist.h"
+#include "feedlistformaction.h"
 #include "filebrowser.h"
+#include "filebrowserformaction.h"
 #include "fmtstrformatter.h"
 #include "formaction.h"
 #include "help.h"
@@ -362,19 +368,22 @@ void View::open_in_pager(const std::string& filename)
 }
 
 nonstd::optional<std::uint8_t> View::open_in_browser(const std::string& url,
-	const std::string& feedurl, bool interactive)
+	const std::string& feedurl, const std::string& type, bool interactive)
 {
 	std::string cmdline;
 	const std::string browser = cfg->get_configvalue("browser");
 	const std::string escaped_url = "'" + utils::replace_all(url, "'", "%27") + "'";
 	const std::string escaped_feedurl = "'" + utils::replace_all(feedurl, "'",
 			"%27") + "'";
+	const std::string quoted_type = "'" + type + "'";
 
 	if (browser.find("%u") != std::string::npos
-		|| browser.find("%F") != std::string::npos) {
+		|| browser.find("%F") != std::string::npos
+		|| browser.find("%t") != std::string::npos) {
 		cmdline = utils::replace_all(browser, {
 			{"%u", escaped_url},
-			{"%F", escaped_feedurl}
+			{"%F", escaped_feedurl},
+			{"%t", quoted_type}
 		});
 	} else {
 		if (browser != "") {
@@ -623,7 +632,7 @@ std::string View::run_dirbrowser()
 	return run_modal(dirbrowser, "filenametext");
 }
 
-std::string View::select_tag()
+std::string View::select_tag(const std::string& current_tag)
 {
 	if (tags.size() == 0) {
 		status_line.show_error(_("No tags defined."));
@@ -635,6 +644,7 @@ std::string View::select_tag()
 	apply_colors(selecttag);
 	selecttag->set_parent_formaction(get_current_formaction());
 	selecttag->set_tags(tags);
+	selecttag->set_selected_value(current_tag);
 	run_modal(selecttag, "");
 	return selecttag->get_selected_value();
 }
